<?php

/*
 * StickySidebar Actions
 * @package wp-dynamic-shortcodes/inc
 * @since   1.2.0
 */

class SSuprydpproActions {

    /**
     * StickySidebar Constructor.
     */
    function __construct() {
        foreach ($this->AjaxActions() as $key => $action) {
            add_action("wp_ajax_{$action['name']}", [$this, $action['callback']]);
            add_action("wp_ajax_nopriv_{$action['name']}", [$this, $action['callback']]);
        }

		add_action( 'wp_ajax_update_cta_status', [$this, 'update_cta_status']);
        add_action( 'wp_ajax_nopriv_update_cta_status', [$this, 'update_cta_status']);

        add_action( 'wp_ajax_change_sticky_sidebar_name', [$this, 'change_sticky_sidebar_name'] );
        add_action( 'wp_ajax_nopriv_change_sticky_sidebar_name', [$this, 'change_sticky_sidebar_name'] );
    }

	public function update_cta_status() {
        global $wpdb;

        $sticky_id = $_POST['sticky_id'];

        $sticky = $wpdb->get_row("SELECT * FROM $wpdb->sticky_cta WHERE id = $sticky_id");
        if ( !$sticky ) {
            wp_send_json( ['success' => false, 'error' => __('Sticky item not exists.', 'wordpress-cta-pro')]);
        }

        $wpdb->update($wpdb->sticky_cta, ['SSuprydp_development' => $_POST['status']], ['id' => $sticky_id]);
        wp_send_json( ['success' => true] );
    }

	public function change_sticky_sidebar_name() {
		global $wpdb;

		$sticky_id = $_POST['sticky'];

		$exists = $wpdb->get_var("SELECT ID FROM {$wpdb->prefix}sticky_cta_options WHERE option_name = 'sidebar_name' AND sticky_cta_id = $sticky_id");

		$data = ['sticky_cta_id' => $sticky_id, 'option_name' => 'sidebar_name', 'option_value' => $_POST['name']];
		if ( $exists ) {
			$data['ID'] = $exists;
		}
		
		$wpdb->replace($wpdb->prefix.'sticky_cta_options', $data);
        die('');
    }

    /*
     * SSuprydpStickySidebar ajax handlers
     *
     * @return Array
     */

    private function AjaxActions() {
        return [
            ['name' => 'process_pages', 'callback' => 'processPages'],
            ['name' => 'ajax_check', 'callback' => 'ajaxCheck'],
            ['name' => 'validate_data', 'callback' => 'validateData'],
        ];
    }

    /**
     *
     * @global type $wpdb
     * @return JSON
     */
    public function processPages() {
        global $wpdb;

		$table_name = $wpdb->prefix.'sticky_cta';

        if(isset($_POST)){
			$postdata = filter_input_array(INPUT_POST, FILTER_SANITIZE_STRING);
			$postdata['SSuprydp_content_option_text'] = wp_kses_stripslashes(wp_kses($_POST['SSuprydp_content_option_text'], wp_kses_allowed_html('post') ));

			$switch_fields = [
				'SSuprydp_target_blank', 'SSuprydp_nofollow',
				'SSuprydp_shrink', 'SSuprydp_shrink_tablet', 'SSuprydp_shrink_mobile', 'SSuprydp_dis_desktop', 'SSuprydp_dis_tablet', 'SSuprydp_dis_mobile',
				'SSuprydp_img_hideimg', 'SSuprydp_hideimg_tablet', 'SSuprydp_hideimg_mobile'
			];

			while ($switch = current($switch_fields)) {
				next($switch_fields);
				if ( !isset($postdata[$switch]) ) {
					$postdata[$switch] = 'No';
				}
			}
			
			if($wpdb->get_var("show tables like '$table_name'") != $table_name) {
				SSuprydpStickySidebar::SSuprydp_plugin_install();
			}

		    if (is_array($postdata)) {
				$postdata['created'] = get_the_date();

				$sticky_id = $postdata['sticky_id'];
				unset($postdata['sticky_id']);

				$postdata['id'] = $sticky_id;
				easy_sticky_sidebar_insert($postdata);
				
				wp_send_json(['status' => 'success', 'message' => 'Saved']);


			} else {
			   wp_send_json(['status' => 'failed', 'message' => 'Data missing']);
			}

			return;
		}

    }
    /**
     * actions init ajaxCheck
     */
    public function ajaxCheck(){
        global $wpdb;

        $table_name = $wpdb->prefix.'sticky_cta';

        if(isset($_POST)){
            $postdata = filter_input_array(INPUT_POST, FILTER_SANITIZE_STRING);;

            if (is_array($postdata)) {

                if(isset($postdata['sticky_id']) && $postdata['sticky_id']>0 ){
                    $id = $postdata['sticky_id'];                    

                    $wpdb->update( $table_name, [$postdata['fildname']=>$postdata['fieldval']], array('id'=>$id));

                }
                echo 'Success';
               exit;

            } else {
               echo 'failed';
               exit;
            }
        }
    }

	/**
     * validate data
     * @param array $postdata
     * @return array
     */
    public function validateData() {

		$postdata = filter_input_array(INPUT_POST, FILTER_SANITIZE_STRING);

        $return = ['errors' => null, 'where' => null];
        $button_text = SSuprydpStickySidebar()->engine->getValue('SSuprydp_button_option_text', $postdata, false);
		
	    if (!$button_text) {
			$return['page_name'] = __("Please enter button text");
			wp_send_json(['status' => 'failed', 'errors' => $return]);
        }
        else{
			$response['status'] = 'success';
            $response['content'] = 'Fields are added successfully.';
            wp_send_json($response);
		}
    }

	private function get_sticky_cta() {
		global $wpdb;

		$table_name = $wpdb->prefix.'sticky_cta';

		$record = apply_filters('get_easy_sticky_cta', $wpdb->get_row("SELECT * FROM $table_name ORDER BY id ASC"));
		if ( !$record ) {
			return false;
		}

		$options = $wpdb->get_results("SELECT * FROM {$wpdb->prefix}sticky_cta_options WHERE sticky_cta_id = $record->id");
		foreach ($options as $option) {
			$record->{$option->option_name} = $option->option_value;
		}

		return $record;
	}

}

new SSuprydpproActions();
