<?php

/**
 * Easy_Sticky_CTA_Generate_CSS
 * @package sticky-sidebar
 * @since   1.3.6
 */
class Easy_Sticky_CTA_Generate_CSS {

    function __construct() {
        add_action( 'init', [$this, 'generate_css_file']);
        add_action('easy_sticky_sidebar_after_save', [$this, 'generate_style']);
    }

    public function generate_css_file() {
        $upload_dir = wp_get_upload_dir();
        $css_file = $upload_dir['basedir'] . '/sticky-sidebar-generated.css';
        if ( !file_exists($css_file)) {
            $this->generate_style();
        }
    }

    public function generate_style() {
        global $wpdb;

        $results = $wpdb->get_results("SELECT * FROM $wpdb->sticky_cta WHERE SSuprydp_development != 'off' ORDER BY id");

        ob_start();
        foreach ($results as $item) {
            $this->item = new WP_Sticky_CTA_Data($item);
            $this->template_style();
            do_action('easy_sticky_sidebar_generate_css', $this->item, $this);
        }

        do_action('easy_sticky_sidebar_after_generate_css');

        $styles = ob_get_clean();

        file_put_contents(wp_upload_dir()['basedir'] . '/sticky-sidebar-generated.css', $styles);
    }

    public function generate_button_style() {
        if ( !empty($this->item->SSuprydp_button_option_color) ) {
            printf("\tcolor: %s;\n", $this->item->SSuprydp_button_option_color); 
        }

        printf("\tfont-family: '%s';\n", $this->item->SSuprydp_button_option_font); 
        printf("\tfont-weight: %s;\n", $this->item->SSuprydp_button_option_weight); 
        printf("\tfont-size: %s;\n", $this->item->SSuprydp_button_option_size); 
        printf("\ttext-align: %s;\n", $this->item->SSuprydp_button_option_align); 

        if ( !empty($this->item->SSuprydp_button_option_backg_color) ) {
            printf("\tbackground-color: %s;\n", $this->item->SSuprydp_button_option_backg_color); 
        }

        do_action( 'easy_sticky_sidebar_generate_button_style', $this->item);
    }

    public function sidebar_image_style() {
        if ( !empty($this->item->sticky_s_media) ) {
            printf("\tbackground-image: url(%s);\n", $this->item->sticky_s_media); 
        }

        if ( absint($this->item->cta_image_height) > 0) {
            printf("\theight: %dpx;\n", $this->item->cta_image_height); 
        }

        do_action( 'easy_sticky_sidebar_generate_image_style', $this->item);
    }

    public function content_style() {
        if ( !empty($this->item->SSuprydp_content_option_color) ) {
            printf("\tcolor: %s;\n", $this->item->SSuprydp_content_option_color); 
        }

        printf("\tfont-family: '%s';\n", $this->item->SSuprydp_content_option_font); 
        printf("\tfont-weight: %s;\n", $this->item->SSuprydp_content_option_weight); 
        printf("\tfont-size: %s;\n", $this->item->SSuprydp_content_option_size); 

        if ( !empty($this->item->content_background_color) ) {
            printf("background-color: %s;\n", $this->item->content_background_color);
        }

        do_action( 'easy_sticky_sidebar_generate_content_style', $this->item);
    }

    public function call_to_action_style() {
        if ( !empty($this->item->SSuprydp_action_option_color) ) {
            printf("\tcolor: %s;\n", $this->item->SSuprydp_action_option_color); 
        }
        
        printf("\tfont-family: '%s';\n", $this->item->SSuprydp_action_option_font); 
        printf("\tfont-weight: %s;\n", $this->item->SSuprydp_action_option_weight); 
        printf("\tfont-size: %s;\n", $this->item->SSuprydp_action_option_size); 
        
        if ( !empty($this->item->link_text_background) ) {
            printf("background-color: %s;\n", $this->item->link_text_background);
        }

        do_action( 'easy_sticky_sidebar_generate_call_to_action_style', $this->item);
    }
    
    function template_style() {
        if ( !in_array($this->item->sidebar_template, ['open-sliding-cta', 'closed-sliding-cta', 'tab-cta', 'html'])) {
            return;
        }

        $sticky_class = sprintf("#easy-sticky-sidebar-%d.easy-sticky-sidebar", $this->item->id);

        printf("%s {\n", $sticky_class);
            if ( $this->item->enable_cta_width == 'yes' && absint($this->item->cta_width) > 0) {
                printf("\t--width: %dpx;\n", $this->item->cta_width); 
            }
            
            do_action( 'easy_sticky_sidebar_wrapper_style', $this->item);
        echo "}\n\n";

        printf("%s .sticky-sidebar-button {\n", $sticky_class);
            $this->generate_button_style();
        echo "}\n\n";

        printf("%s .sticky-sidebar-image {\n", $sticky_class);
            $this->sidebar_image_style();
        echo "}\n\n";

        printf("%s .sticky-sidebar-text {\n", $sticky_class);
            $this->content_style();
        echo "}\n\n";

        printf("%s .sticky-sidebar-content hr {\n", $sticky_class);
            if ( !empty($this->item->line_separator_color) ) {
                printf("\tbackground-color: %s;\n", $this->item->line_separator_color); 
            }
        echo "}\n\n";

        printf("%s .sticky-sidebar-call-to-action {\n", $sticky_class);
            $this->call_to_action_style();
        echo "}\n\n";
    }

}

return new Easy_Sticky_CTA_Generate_CSS();