<?php

/**
 * check if pro available or not
 * @since  1.3.6
 */
function has_wordpress_cta_pro() {
    return class_exists('Wordpress_CTA_Pro');
}

/**
 * check if pro available or not
 * @since  1.3.8
 */
function get_easy_sticky_sidebar_header($class = '') { ?>
    <header class="easy-sticky-sidebar-header">
        <div class="easy-sticky-sidebar-container <?php echo $class ?>">
            <h3 class="">WordPress CTA</h3>
        </div>
    </header>
    <?php
}

/**
 * Insert CTA Post
 * @since  1.3.8
 */
function easy_sticky_sidebar_insert($args) {
    if ( is_object($args) ) {
        $args = (array) $args;
    }

    if ( !is_array($args)) {
        return false;
    }

    $sticky_id = absint( @$args['id'] ) ?: false;
    $is_new = ($sticky_id == false);

    $args = (array) apply_filters('easy_sticky_sidebar_args', $args, $sticky_id, $is_new);

    global $wpdb;
    $sticky_cta_columns = $wpdb->get_col("DESC {$wpdb->sticky_cta}", 0);

    $main_fields = $meta_fields = [];
    foreach ($args as $key => $value) {
        if ( in_array($key, $sticky_cta_columns)) {
            $main_fields[$key] = $value;
            continue;
        }

        $meta_fields[$key] = $value;
    }

    if ( $is_new ) {
        $wpdb->insert($wpdb->sticky_cta, $main_fields);
        $sticky_id = $wpdb->insert_id;
    } else {
        $wpdb->update($wpdb->sticky_cta, $main_fields, ['id' => $sticky_id]);
    }

    if ( !$sticky_id ) {
        return false;
    }

    if ( count($meta_fields) > 0 && $wpdb->get_var("SELECT id FROM $wpdb->sticky_cta WHERE id = $sticky_id") ) {        
        foreach ($meta_fields as $meta_key => $meta_value) {

            $exists = $wpdb->get_var("SELECT ID FROM $wpdb->sticky_cta_options WHERE option_name = '$meta_key' AND sticky_cta_id = $sticky_id");

            $data = ['sticky_cta_id' => $sticky_id, 'option_name' => $meta_key, 'option_value' => maybe_serialize($meta_value)];
            if ( $exists ) {
                $data['ID'] = $exists;
            }
            
            $wpdb->replace($wpdb->sticky_cta_options, $data);   
        }        
    }

    do_action( 'easy_sticky_sidebar_after_save', $args, $sticky_id, $is_new);

    return $sticky_id;
}

/**
 * Get Sticky CTA item
 * @since  1.3.8
 */
function get_easy_sticky_sidebar($sticky_id) {
    global $wpdb;

    $sticky_data = $wpdb->get_row("SELECT * FROM $wpdb->sticky_cta WHERE id = $sticky_id");
    if ( !$sticky_data ) {
        return false;        
    }

    return new WP_Sticky_CTA_Data($sticky_data);
}

/**
 * Returns options of a cta item
 * @since  1.3.5
 */
function easy_sticky_sidebar_templates() {
    return apply_filters('easy_sticky_sidebar_templates', [
        'open-sliding-cta' => __('Open Sliding CTA', 'easy-sticky-sidebar'),
        'closed-sliding-cta' => __('Closed Sliding CTA', 'easy-sticky-sidebar'),
        'tab-cta' => __('Tab CTA', 'easy-sticky-sidebar')
    ]);
}

/**
 * Returns status menu
 * @since  1.3.8
 */
function get_easy_sticky_sidebar_get_status_menu($stickycta) {    
    $statuses = [
        'live'          => __('Live', 'wordpress-cta-pro'),
        'development'   => __('Development', 'wordpress-cta-pro'),
        'off'           => __('Off', 'wordpress-cta-pro'),
    ]; ?>

    <div class="sticky-cta-status-menu" data-id="<?php echo $stickycta->id ?>">
        <input type="hidden" name="SSuprydp_development" value="<?php echo $stickycta->SSuprydp_development; ?>">
        <label class="status-<?php echo $stickycta->SSuprydp_development; ?>"><?php echo $statuses[$stickycta->SSuprydp_development]  ?></label>
        <ul class="statuses">
            <?php foreach ($statuses as $status_key => $status_label) {
                printf('<li data-status="%s">%s</li>', $status_key, $status_label);
            } ?>
        </ul>
    </div>
    <?php
}

/**
 * return unique cta name
 * @since  1.3.8
 */

function get_unique_easy_sticky_sidebar_name($name, $number = false) {
    global $wpdb;

    $next_name = $name . ' - Copy';
    if ( $number ) {
        $next_name = $next_name . ' ' . $number;
    }

    $has_name = $wpdb->get_row("SELECT * FROM $wpdb->sticky_cta_options WHERE option_name = 'sidebar_name' AND option_value = '$next_name' LIMIT 0, 1");

    if ( !$has_name ) {
        return $next_name;
    }

    if ( absint($number) == 0 ) {
        $number = 2;
    } else {
        $number++;
    }

    return get_unique_easy_sticky_sidebar_name($name, $number);
}